@@ -1,7 +1,7 @@
 use strict;
 use warnings;
 
-use Smart::Comments;
+#use Smart::Comments;
 use lib 'lib';
 use OpenResty::RestyScript::View;
 
