@@ -18,6 +18,7 @@ our @EXPORT = qw(
     $VIEW_MAX_LEN
     $ACTION_MAX_LEN
     $ACTION_CMD_COUNT_LIMIT
+    $ACTION_REC_DEPTH_LIMIT
 );
 
 our $MODEL_LIMIT = 40;
@@ -33,5 +34,6 @@ our $PASSWORD_MIN_LEN = 6;
 our $VIEW_MAX_LEN = 5_000; # 5 KB
 our $ACTION_MAX_LEN = 5_000; # 5 KB
 our $ACTION_CMD_COUNT_LIMIT = 5;
+our $ACTION_REC_DEPTH_LIMIT = 3;
 
 1;
